Social network analysis can be used to identify individuals or groups that are structurally in a position to influence flows of information or material over a network. In our case, the relevant metrics are 'betweenness centrality' and 'eigenvector centrality'. Betweenness looks at every pair of nodes in a network, and works out the shortest path between them. For each node, the routine works out the number of shortest paths that the node participates in. The more paths, the greater the score; the more paths, the greater the indication that that node is in a position to influence what flows through the network. Eigenvector is similar, but conceives of importance as a function of being well connected to well connected other nodes.

The first task is to convert the list of groups and admins into two separate lists: one where groups are connected to other groups by virtue of shared administrators (and the number of shared administrators increases the weight or strength of the connection), and one where subjects are connected to other subjects by virtue of administrating the same group. When two individuals are administrators of the same groups (they have groups in common), the strength of their connection is increased. Reshaping the list into two separate networks was done using Gephi and its multi-mode projection plugin. Social network analysis were conducted within Gephi also.

The top five individiuals, by betweenness centrality, were

Subject   --  Location
subject_470	Michigan City, Indiana
subject_313	Irbid, Jordan
subject_303	Benha, Egypt
subject_227	N/A
subject_237	N/A

Using the eigenvector centrality measure, the results were slightly different:

Subject  --  Location
subject_303	Benha, Egypt
subject_470	Michigan City, Indiana
subject_167	Amman, Jordan
subject_119	Antakya, Hatay, Turkey
subject_420	Tripoli, Libya

We can also explore the larger network structure to detect 'communities' within this patterning of connections. We use Gephi's 'modularity' statistic. This approach looks for patterns of similar local connections; it is probabilistic in the sense that it can be attentuated to pay attention to larger or smaller subgroupings. Using the default values, the resulting partition is reasonably strong (72.7). Five subgroups account for about 50% of the structure of this network:

Module 43: 15.31%
Module 30: 10%
Module 49: 9.59%
Module 26: 9.18%
Module 37: 8.16%

These are visualized in the accompanying pdfs. The size of the node is scaled against its betweenness score. The nodes are laid out using a force-atlas routine that seeks to untangle the knots as best as it can (thus, the x, y coordinates of the nodes are not meaningful) These modules all interconnect with each other, making one larger cluster. As the visualization 'subjects-to-subjects-via-shared-groups.pdf' demonstrates, there are a number of 'isolated' clusters that have not yet been connected into this larger network of individuals. Those isolated clusters may bear examination.

All calculated stats are in the subjects-to-subjects-all-stats.csv file.

---
Groups
---

If we express the network as groups connected to other groups by virtue of shared administrators, we see a very tight nexus of relationships between the groups. The average degree is around 3, meaning that groups are connected to three other groups on average; however, the distribution is actually quite uneven, with 35 groups having no other connections, 14 groups having 1 connections, 4 groups with 2 connections, 10 groups having 3 connections each, and as we travel down the 'long tail', a number of groups having 8 or more connections. 1 group has 22 connections to other groups.

The top groups by betweenness are:
group -- betweenness score
group_I	147.6054029
group_T	129.654082
group_Q1	104.9673909
group_X	61.65366023
group_T1	57.34967532
group_E3	42.9977689
group_F	35.58333333
group_R1	35.25952381
group_H1	25.29762182
group_K1	17.74499389

The top 10 by eigenvector centrality are:

group_I
group_T
group_X
group_D
group_Q1
group_E3
group_Z
group_K1
group_F1
group_V

Groups that score highly on both metrics merit closer attention. In the visualizations for groups, the size of the node is scaled against its betweenness centrality score. The thickness of the edge is a function of the number of administrators a pair of groups (nodes) have in common.

All calculated stats are in the groups-to-groups-all-stats.csv file.

----

Gephi:
Bastian M., Heymann S., Jacomy M. (2009). Gephi: an open source software for exploring and manipulating networks. International AAAI Conference on Weblogs and Social Media.

Modularity routine:
Vincent D Blondel, Jean-Loup Guillaume, Renaud Lambiotte, Etienne Lefebvre, Fast unfolding of communities in large networks, in Journal of Statistical Mechanics: Theory and Experiment 2008 (10), P1000

Betweenness centrality:
Ulrik Brandes, A Faster Algorithm for Betweenness Centrality, in Journal of Mathematical Sociology 25(2):163-177, (2001)
